Introduction
============

`NetBox <https://github.com/digitalocean/netbox/>`_ is an IP address management
(`IPAM <https://en.wikipedia.org/wiki/IP_address_management>`_) and data center
infrastructure management (`DCIM <https://en.wikipedia.org/wiki/Data_center_infrastructure_management>`_)
application developed by `DigitalOcean <https://digitalocean.com/>`_.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.0``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.netbox

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
